twitter.api.streaming


*site-stream-api*clj

source

*streaming-api*clj

source

*user-stream-api*clj

source

def-twitter-site-streaming-methodcljmacro

(def-twitter-site-streaming-method name verb resource-path & rest)

defines a site streaming method using the above context

defines a site streaming method using the above context
sourceraw docstring

def-twitter-streaming-methodcljmacro

(def-twitter-streaming-method name verb resource-path & rest)

defines a streaming API method using the above api context

defines a streaming API method using the above api context
sourceraw docstring

def-twitter-user-streaming-methodcljmacro

(def-twitter-user-streaming-method name verb resource-path & rest)

defines a user streaming method using the above context

defines a user streaming method using the above context
sourceraw docstring

site-streamclj

(site-stream & {:as args__6425__auto__})
source

statuses-filterclj

(statuses-filter & {:as args__6425__auto__})
source

statuses-firehoseclj

(statuses-firehose & {:as args__6425__auto__})
source

statuses-sampleclj

(statuses-sample & {:as args__6425__auto__})
source

user-streamclj

(user-stream & {:as args__6425__auto__})
source

cljdoc builds & hosts documentation for Clojure/Script libraries