twitter.callbacks


callbacks-async-single-defaultclj

(callbacks-async-single-default)

prints on every state

prints on every state
sourceraw docstring

callbacks-async-streaming-defaultclj

(callbacks-async-streaming-default)

prints on every state

prints on every state
sourceraw docstring

callbacks-sync-single-debugclj

(callbacks-sync-single-debug)

returns the whole response (un-transformed) to the caller, regardless of an error occuring

returns the whole response (un-transformed) to the caller, regardless of an error occuring
sourceraw docstring

callbacks-sync-single-defaultclj

(callbacks-sync-single-default)

throws on error otherwise returns the whole response to the caller

throws on error otherwise returns the whole response to the caller
sourceraw docstring

callbacks-sync-single-printclj

(callbacks-sync-single-print)

just prints out whatever it gets

just prints out whatever it gets
sourceraw docstring

callbacks-sync-streaming-defaultclj

(callbacks-sync-streaming-default)

prints the exception, prints the status error or prints out the streaming response to the caller

prints the exception, prints the status error or prints out the streaming response to the caller
sourceraw docstring

get-default-callbacksclj

(get-default-callbacks async-sync single-streaming)

returns the default callbacks to use for a supplied sync-type/call-type combination

returns the default callbacks to use for a supplied sync-type/call-type combination
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries