(bodypart-print _ baos)prints out the data received from the streaming callback
prints out the data received from the streaming callback
(exception-print _ throwable)prints the string version of the throwable object
prints the string version of the throwable object
(exception-rethrow _ throwable)prints the string version of the throwable object
prints the string version of the throwable object
(get-twitter-error-message response)interrogates a response for its twitter error message
interrogates a response for its twitter error message
(handle-response response
callbacks
&
{:keys [events] :or {events #{:on-success :on-failure}}})takes a response and reacts to success or error. 'events' should be a set of keywords like #{:on-success :on-failure}
takes a response and reacts to success or error.
'events' should be a set of keywords like #{:on-success :on-failure}(rate-limit-error? status)returns true if the given response contains a rate limit error
returns true if the given response contains a rate limit error
(response-return-body response)this takes a response and returns the json-parsed body
this takes a response and returns the json-parsed body
(response-return-everything response & {:keys [to-json?] :or {to-json? true}})this takes a response and returns a map of the headers and the json-parsed body
this takes a response and returns a map of the headers and the json-parsed body
(response-throw-error response)throws the supplied error in an exception
throws the supplied error in an exception
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |