(execute-request-callbacks client req callbacks)submits the request and then calls back to the callbacks
submits the request and then calls back to the callbacks
(file-body-part file-name)takes a filename and returns a 'Part' object that can be added to the request
takes a filename and returns a 'Part' object that can be added to the request
(get-response-transform callbacks)returns a function that transforms the response into the desired outcome, depending on the request state
returns a function that transforms the response into the desired outcome, depending on the request state
(prepare-request-with-multi method
url
&
{:keys [headers query body cookies proxy auth
timeout]})the same as a normal prepare-request, but deals with multi-part form-data as a content-type
the same as a normal prepare-request, but deals with multi-part form-data as a content-type
(status-body-part status)takes a filename and returns a 'Part' object that can be added to the request
takes a filename and returns a 'Part' object that can be added to the request
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |